@@ -39,8 +39,7 @@ def sync(
     api: BaiduPCSApi,
     localdir: str,
     remotedir: str,
-    encrypt_key: bytes = b"",
-    salt: bytes = b"",
+    encrypt_password: bytes = b"",
     encrypt_type: EncryptType = EncryptType.No,
     max_workers: int = CPU_NUM,
     slice_size: int = DEFAULT_SLICE_SIZE,
@@ -90,8 +89,7 @@ def sync(
     _upload(
         api,
         fts,
-        encrypt_key=encrypt_key,
-        salt=salt,
+        encrypt_password=encrypt_password,
         encrypt_type=encrypt_type,
         max_workers=max_workers,
         slice_size=slice_size,
